@@ -1,11 +1,12 @@
 package App::Office::CMS::Controller::Search;
 
 use parent 'App::Office::CMS::Controller';
-use common::sense;
+use strict;
+use warnings;
 
-# We don't use Moose because we isa CGI::Application.
+# We don't use Moo because we isa CGI::Application.
 
-our $VERSION = '0.92';
+our $VERSION = '0.93';
 
 # -----------------------------------------------
 
