@@ -1,32 +1,33 @@
 package App::Office::CMS::Util::Config;
 
-use Any::Moose;
-use common::sense;
+use strict;
+use warnings;
 
 use Config::Tiny;
 
+use Moo;
+
+use Types::Standard qw/Any/;
+
 has config =>
 (
 	is  => 'rw',
-	isa => 'Any',
+	isa => Any,
 );
 
 has config_file_path =>
 (
 	is  => 'rw',
-	isa => 'Any',
+	isa => Any,
 );
 
 has section =>
 (
 	is  => 'rw',
-	isa => 'Any',
+	isa => Any,
 );
 
-# If Moose...
-#use namespace::autoclean;
-
-our $VERSION = '0.92';
+our $VERSION = '0.93';
 
 # -----------------------------------------------
 
@@ -73,9 +74,4 @@ sub BUILD
 
 # --------------------------------------------------
 
-no Any::Moose;
-
-# If Moose...
-#__PACKAGE__ -> meta -> make_immutable;
-
 1;
